/****************************************************************************
* Title                 :   Stretch click
* Filename              :   Stretch.c
* Author                :   Lana Arsic
* Origin Date           :   27/06/2016
* Notes                 :   Stretch Example
*****************************************************************************/
/**************************CHANGE LIST **************************************
*
*    Date    Software Version    Initials       Description
*  27/06/16       3.6.0            LA        This is a demonstration of using Stretch click.
                                             Analog value on AN pin increases when stretching
*
*****************************************************************************/
/**
 * @file Stretch.c
 * @brief <h2> Stretch Example </h2>
 *
 * @par
 * Example for <a href="http://www.mikroe.com">MikroElektronika's</a>
 * Stretch click board.
 */
 
#include "Stretch.h"
#include "resources.h"

static unsigned int adc_rd;
static char txt[6];

// TFT module connections
char TFT_DataPort at LATE;
sbit TFT_RST at LATD7_bit;
sbit TFT_BLED at LATD2_bit;
sbit TFT_RS at LATD9_bit;
sbit TFT_CS at LATD10_bit;
sbit TFT_RD at LATD5_bit;
sbit TFT_WR at LATD4_bit;

char TFT_DataPort_Direction at TRISE;
sbit TFT_RST_Direction at TRISD7_bit;
sbit TFT_BLED_Direction at TRISD2_bit;
sbit TFT_RS_Direction at TRISD9_bit;
sbit TFT_CS_Direction at TRISD10_bit;
sbit TFT_RD_Direction at TRISD5_bit;
sbit TFT_WR_Direction at TRISD4_bit;
// End TFT module connections

void Display_Init()
{
    TFT_Init_ILI9341_8bit(320, 240);
    TFT_BLED = 1;
    TFT_Set_Pen(CL_WHITE, 1);
    TFT_Set_Brush(1,CL_WHITE,0,0,0,0);
    TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
    TFT_Fill_Screen(CL_WHITE);
    TFT_Set_Pen(CL_Black, 1);
    TFT_Line(20, 220, 300, 220);
    TFT_LIne(20,  46, 300,  46);
    TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
    TFT_Write_Text("Stretch Click", 85, 14);
    TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
    TFT_Write_Text("EasyPIC Fusion v7", 19, 223);
    TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
    TFT_Write_Text("www.mikroe.com", 200, 223);
}

/*
 * Read data from sensor
 * reads ADC value from AN pin
 */
static void readSensor()
{
    adc_rd = ADC1_Get_Sample(8);               // Get ADC value from corresponding channel
    delay_ms(10);                              // Pause 10ms
}

/*
 * Set A/D register
 * set ADC on RB8
 */
static void set_adc()
{
    AD1PCFG = 0xFFEF;                        // Configure AN pins as digital I/O
    JTAGEN_bit = 0;                          // Disable JTAG port
    ADC1_Init();                             // Init
    Delay_ms(100);
}

void main() 
{
    set_adc();                                                         // Set A/D register
    Display_Init();                                                    // Initialize TFT
    TFT_Set_Pen(CL_WHITE, 1);
    TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
    while(1)
    {
        readSensor();                                                  // Read sensor
        TFT_Set_Font(&TFT_defaultFont, CL_WHITE, FO_HORIZONTAL);
        TFT_Write_Text(txt, 140, 100);
        WordToStr(adc_rd,&txt);                                        // Conversion integer adc_rd to string txt
        TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);       // Display string on TFT
        TFT_Write_Text(txt,140,100);                                   // Print txt value on TFT
        delay_ms(500);
    }
}